ttyprompt reads a line of text from the terminal.

|image0| |image1|

.. |image0| image:: https://travis-ci.org/eliteraspberries/ttyprompt.svg
   :target: https://travis-ci.org/eliteraspberries/ttyprompt
.. |image1| image:: https://codecov.io/github/eliteraspberries/ttyprompt/coverage.svg
   :target: https://codecov.io/github/eliteraspberries/ttyprompt
